Plone JSON API Routes
=====================

:Author: Ramon Bartl (RIDING BYTES - http://ridingbytes.com)
:Version: 0.9.2


.. contents:: Table of Contents
   :depth: 2


Lastest Build Status
--------------------

Master Branch https://github.com/collective/plone.jsonapi.routes

.. image:: https://api.travis-ci.org/collective/plone.jsonapi.routes.png?branch=master
    :target: https://travis-ci.org/collective/plone.jsonapi.routes
    :alt: Build Status

.. image:: https://readthedocs.org/projects/pip/badge/
  :target: https://plonejsonapiroutes.readthedocs.org


Introduction
------------

This is an add-on package for plone.jsonapi.core_ which provides some basic
URLs for Plone standard contents (and more).


Motivation
----------

The routes package is built on top of the plone.jsonapi.core_ package to allow
Plone developers to build modern (JavaScript) web UIs which communicate through
a RESTful_ API with their Plone site.


Compatibility
-------------

The plone.jsonapi.routes_ is compatible with Plone_ 4 and 5.


Documentation
-------------

http://plonejsonapiroutes.readthedocs.org

Source:

https://github.com/collective/plone.jsonapi.routes/tree/master/docs


See it in action
----------------

A small tec demo is available on youtube:

http://www.youtube.com/watch?v=MiwgkWLMUqk


License
-------

MIT - do what you want


.. Links

.. _Plone: http://plone.org
.. _Dexterity: https://pypi.python.org/pypi/plone.dexterity
.. _Werkzeug: http://werkzeug.pocoo.org
.. _plone.jsonapi.core: https://github.com/collective/plone.jsonapi.core
.. _plone.jsonapi.routes: https://github.com/collective/plone.jsonapi.routes
.. _plone.jsonapi.example: https://github.com/collective/plone.jsonapi.example
.. _mr.developer: https://pypi.python.org/pypi/mr.developer
.. _Utility: http://developer.plone.org/components/utilities.html
.. _CRUD: http://en.wikipedia.org/wiki/CRUD
.. _curl: http://curl.haxx.se/
.. _RESTful: http://en.wikipedia.org/wiki/Representational_state_transfer
.. _pypi: http://pypi.python.org
